@@ -193,6 +193,20 @@ static void loading(void)
 
 	driver = NULL;	
 	cp = keyengine.getLast("driver");
+#ifndef	WIN32
+	if(cp && !stricmp(cp, "autodetect"))
+	{
+		cp = Process::getEnv("DRIVER_AUTODETECT");
+		if(!cp || !*cp)
+			cp = "default";
+	}
+	if(cp && !stricmp(cp, "default"))
+	{
+		cp = Process::getEnv("DRIVER");
+		if(!cp || !*cp)
+			cp = "soundcard";
+	}
+#endif
 	if(cp && *cp)
 		driver = BayonneDriver::loadDriver(cp);
 
@@ -478,6 +492,15 @@ int main(int argc, char **argv)
                         stop(-1);
                 }
         }
+	cp = keyengine.getLast("driver");
+	if(cp && !stricmp(cp, "autodetect"))
+	{
+		cp = Process::getEnv("DRIVER_AUTODETECT");
+		if(!cp || !*cp)
+			cp = Process::getEnv("DRIVER");
+		if(!cp || !*cp)
+			Bayonne::provision_daemon = false;
+	}
 	if(Bayonne::provision_daemon)
 		Process::detach();
 
