@@ -5,7 +5,7 @@ from libexec import Libexec
 if __name__ == '__main__':
 	tgi = Libexec()
 	tgi.echo("LIBEXEC STARTED")
-	result = tgi.prompt("&number 123")
+	result = tgi.speak("&number 123")
 	tgi.echo("PROMPT DONE, RESULT=%d" % result)
 	tgi.result(result)
 
